import chalk from "chalk";
import { $ } from "execa";
async function getGitHubUserAsAllContributor(octokit, options) {
  if (options.offline) {
    console.warn(
      chalk.gray(
        `Skipping populating all-contributors contributions for ${options.owner} because in --offline mode.`
      )
    );
    return options.owner;
  }
  let user;
  if (octokit) {
    try {
      user = (await octokit.rest.users.getAuthenticated()).data.login;
    } catch {
      console.warn(
        chalk.gray(
          `Couldn't authenticate GitHub user, falling back to the provided owner name '${options.owner}'.`
        )
      );
      user = options.owner;
    }
  } else {
    user = options.owner;
  }
  const contributions = [
    "code",
    "content",
    "doc",
    "ideas",
    "infra",
    "maintenance",
    "projectManagement",
    "tool"
  ].join(",");
  await $`pnpx all-contributors-cli@6.25 add ${user} ${contributions}`;
  return user;
}
export {
  getGitHubUserAsAllContributor
};
//# sourceMappingURL=getGitHubUserAsAllContributor.js.map