import chalk from "chalk";
import { execaCommand } from "execa";
import { rimraf } from "rimraf";
import { logLine } from "../shared/cli/lines.js";
import { withSpinner } from "../shared/cli/spinners.js";
async function runCleanup(commands, mode) {
  const failed = [];
  await withSpinner("Cleaning up files", async () => {
    if (mode === "migrate") {
      await rimraf("coverage*");
    }
    for (const command of commands) {
      try {
        await execaCommand(command);
      } catch {
        failed.push(command);
      }
    }
  });
  if (!failed.length) {
    return;
  }
  logLine();
  for (const command of failed) {
    logLine(
      [
        chalk.yellow(`\u{1F7E1} Running \``),
        chalk.yellowBright(command),
        chalk.yellow(`\` failed. You should run it and fix its complaints.`)
      ].join("")
    );
  }
}
export {
  runCleanup
};
//# sourceMappingURL=runCleanup.js.map